.wrapper {
  padding: 3 3;
  position: relative;
  top: 0;
  bottom: 0;
  left: 0;
  right: 0;
  height: 100%;
}

.slidecontainer {
  background-color: #DCDCDC;
  color: #000;
  padding: 2px;
  border: 1px solid #000;
  text-align: left;
  border-radius: 10px;
  position: absolute;
  margin: 0;
  opacity: 0.75;
  z-index: 15;
  bottom: 25px;
  right: 5px;
}

.collapsible {
  background-color: #DCDCDC;
  cursor: pointer;
  padding: 2px;
  border: none;
  text-align: left;
  outline: none;
}

/* Add a background color to the button if it is clicked on (add the .active class with JS), and when you move the mouse over it (hover) */
.collapsible:hover {
  background-color: #D3D3D3;
}
