{% extends "django_large_image/base.html" %}
{% block content %}
<script>
  var tileUrl = `${host}/${baseEndpoint}/${imageId}/tiles/{z}/{x}/{y}.png`;
</script>

<div class="wrapper">
  {% include 'django_large_image/_include/geojs.html' %}
</div>

{% endblock content %}
